Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(491)

Unified Diff: content/browser/frame_host/render_frame_host_impl.cc

Issue 2484633004: Change Lo-Fi bool to bitmask to support multiple Previews types (Closed)
Patch Set: use PreviewsState everywhere Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/frame_host/render_frame_host_impl.cc
diff --git a/content/browser/frame_host/render_frame_host_impl.cc b/content/browser/frame_host/render_frame_host_impl.cc
index 34c8572c4391e87f2198abd6d78498ecbe4be1c4..fe6b5dc8e047f9d55b79fa7feee00f72957dd3d7 100644
--- a/content/browser/frame_host/render_frame_host_impl.cc
+++ b/content/browser/frame_host/render_frame_host_impl.cc
@@ -334,7 +334,7 @@ RenderFrameHostImpl::RenderFrameHostImpl(SiteInstance* site_instance,
pending_web_ui_type_(WebUI::kNoWebUI),
should_reuse_web_ui_(false),
has_selection_(false),
- last_navigation_lofi_state_(LOFI_UNSPECIFIED),
+ last_navigation_previews_state_(PREVIEWS_UNSPECIFIED),
frame_host_binding_(this),
waiting_for_init_(renderer_initiated_creation),
weak_ptr_factory_(this) {
@@ -2405,7 +2405,7 @@ void RenderFrameHostImpl::NavigateToInterstitialURL(const GURL& data_url) {
data_url, Referrer(), ui::PAGE_TRANSITION_LINK,
FrameMsg_Navigate_Type::NORMAL, NavigationGestureAuto, false, false,
base::TimeTicks::Now(), FrameMsg_UILoadMetricsReportType::NO_REPORT,
- GURL(), GURL(), LOFI_OFF, base::TimeTicks::Now(), "GET", nullptr);
+ GURL(), GURL(), PREVIEWS_OFF, base::TimeTicks::Now(), "GET", nullptr);
if (IsBrowserSideNavigationEnabled()) {
CommitNavigation(nullptr, nullptr, common_params, RequestNavigationParams(),
false);
@@ -2588,9 +2588,9 @@ void RenderFrameHostImpl::CommitNavigation(
Send(new FrameMsg_CommitNavigation(routing_id_, head, body_url, common_params,
request_params));
// If a network request was made, update the LoFi state.
if (ShouldMakeNetworkRequestForURL(common_params.url))
- last_navigation_lofi_state_ = common_params.lofi_state;
+ last_navigation_previews_state_ = common_params.previews_state;
// TODO(clamy): Release the stream handle once the renderer has finished
// reading it.
@@ -2588,9 +2588,9 @@ void RenderFrameHostImpl::CommitNavigation(
Send(new FrameMsg_CommitNavigation(routing_id_, head, body_url, common_params,
request_params));
- // If a network request was made, update the LoFi state.
+ // If a network request was made, update the Previews state.
if (ShouldMakeNetworkRequestForURL(common_params.url))

Powered by Google App Engine
This is Rietveld 408576698